@@ -1,11 +1,11 @@
-import { CommonModule } from "@angular/common";
-import { HttpClientModule } from "@angular/common/http";
-import { NgModule } from "@angular/core";
-import { Routes } from "@angular/router";
-import { FormsModule } from "@angular/forms";
-import { NzIconModule } from "ng-zorro-antd/icon";
-import { RouterModule } from "@angular/router";
-import { DocdbComponent } from "./graphdb.component";
+import { CommonModule } from "@angular/common"
+import { HttpClientModule } from "@angular/common/http"
+import { NgModule } from "@angular/core"
+import { Routes } from "@angular/router"
+import { FormsModule } from "@angular/forms"
+import { NzIconModule } from "ng-zorro-antd/icon"
+import { RouterModule } from "@angular/router"
+import { DocdbComponent } from "./graphdb.component"
 import {
     TupleActionPushNameService,
     TupleActionPushOfflineService,
@@ -15,14 +15,14 @@ import {
     TupleDataOfflineObserverService,
     TupleOfflineStorageNameService,
     TupleOfflineStorageService,
-} from "@synerty/vortexjs";
+} from "@synerty/vortexjs"
 import {
     graphDbFilt,
     graphDbObservableName,
     graphDbTupleOfflineServiceName,
     graphDbActionProcessorName,
-} from "@peek/peek_plugin_graphdb/_private/PluginNames";
-import { ViewTraceComponent } from "./view-trace/view.component";
+} from "@peek/peek_plugin_graphdb/_private/PluginNames"
+import { ViewTraceComponent } from "./view-trace/view.component"
 
 // Define the child routes for this plugin.
 export const pluginRoutes: Routes = [
@@ -39,7 +39,7 @@ export const pluginRoutes: Routes = [
         pathMatch: "full",
         component: DocdbComponent,
     },
-];
+]
 
 // Define the root module for this plugin.
 // This module is loaded by the lazy loader, what ever this defines is what is started.
@@ -56,4 +56,5 @@ export const pluginRoutes: Routes = [
     providers: [],
     declarations: [DocdbComponent, ViewTraceComponent],
 })
-export class GraphDbModule {}
+export class GraphDbModule {
+}
