@@ -1,9 +1,10 @@
 import logging
 from typing import Optional
 
-from peek_abstract_chunked_index.private.server.client_handlers.ACIChunkLoadRpcABC import \
-    ACIChunkLoadRpcABC
-from peek_plugin_base.PeekVortexUtil import peekServerName, peekClientName
+from peek_abstract_chunked_index.private.server.client_handlers.ACIChunkLoadRpcABC import (
+    ACIChunkLoadRpcABC,
+)
+from peek_plugin_base.PeekVortexUtil import peekServerName, peekBackendNames
 from peek_plugin_base.storage.DbConnection import DbSessionCreator
 from peek_plugin_graphdb._private.PluginNames import graphDbFilt
 from peek_plugin_graphdb._private.storage.GraphDbEncodedChunk import GraphDbEncodedChunk
@@ -19,7 +20,7 @@ class SegmentIndexChunkLoadRpc(ACIChunkLoadRpcABC):
         self._dbSessionCreator = dbSessionCreator
 
     def makeHandlers(self):
-        """ Make Handlers
+        """Make Handlers
 
         In this method we start all the RPC handlers
         start() returns an instance of it's self so we can simply yield the result
@@ -31,10 +32,15 @@ class SegmentIndexChunkLoadRpc(ACIChunkLoadRpcABC):
         logger.debug("RPCs started")
 
     # -------------
-    @vortexRPC(peekServerName, acceptOnlyFromVortex=peekClientName, timeoutSeconds=60,
-               additionalFilt=graphDbFilt, deferToThread=True)
+    @vortexRPC(
+        peekServerName,
+        acceptOnlyFromVortex=peekBackendNames,
+        timeoutSeconds=60,
+        additionalFilt=graphDbFilt,
+        deferToThread=True,
+    )
     def loadSegmentChunks(self, offset: int, count: int) -> Optional[bytes]:
-        """ Load Segment Chunks
+        """Load Segment Chunks
 
         Allow the client to incrementally load the chunks.
 
@@ -42,16 +48,22 @@ class SegmentIndexChunkLoadRpc(ACIChunkLoadRpcABC):
         chunkTable = GraphDbEncodedChunk.__table__
         msTable = GraphDbModelSet.__table__
 
-        sql = select([msTable.c.key,
-                      chunkTable.c.chunkKey,
-                      chunkTable.c.encodedData,
-                      chunkTable.c.encodedHash,
-                      chunkTable.c.lastUpdate]) \
-            .select_from(chunkTable.join(msTable)) \
-            .order_by(chunkTable.c.chunkKey) \
-            .offset(offset) \
+        sql = (
+            select(
+                [
+                    msTable.c.key,
+                    chunkTable.c.chunkKey,
+                    chunkTable.c.encodedData,
+                    chunkTable.c.encodedHash,
+                    chunkTable.c.lastUpdate,
+                ]
+            )
+            .select_from(chunkTable.join(msTable))
+            .order_by(chunkTable.c.chunkKey)
+            .offset(offset)
             .limit(count)
+        )
 
-        return self.ckiInitialLoadChunksPayloadBlocking(offset, count,
-                                                        GraphDbEncodedChunk,
-                                                        sql)
+        return self.ckiInitialLoadChunksPayloadBlocking(
+            offset, count, GraphDbEncodedChunk, sql
+        )
